X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/91671b558fea0f751b36a4ae6fb796751af0ca4a..69be160e37ee908eabc52d5f7ca2294651b252eb:/Controller/ApplicationController.php

diff --git a/Controller/ApplicationController.php b/Controller/ApplicationController.php
index 45538ff..deab095 100644
--- a/Controller/ApplicationController.php
+++ b/Controller/ApplicationController.php
@@ -3,6 +3,7 @@
 namespace Rapsys\AirBundle\Controller;
 
 use Symfony\Component\HttpFoundation\Request;
+use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Routing\RequestContext;
 use Symfony\Component\Form\FormError;
 use Symfony\Component\Routing\Exception\MethodNotAllowedException;
@@ -124,21 +125,24 @@ class ApplicationController extends DefaultController {
 					$session->setLength(new \DateTime('05:00:00'));
 				//Check if afternoon
 				} elseif ($slot == 'Afternoon') {
-					//Set begin at 14h
-					$session->setBegin(new \DateTime('14:00:00'));
+					//Set begin at 16h
+					$session->setBegin(new \DateTime('16:00:00'));
 
-					//Set length at 5h
-					$session->setLength(new \DateTime('05:00:00'));
+					//Set length at 3h
+					$session->setLength(new \DateTime('03:00:00'));
 				//Check if evening
 				} elseif ($slot == 'Evening') {
-					//Set begin at 19h
-					$session->setBegin(new \DateTime('19:00:00'));
+					//Set begin at 20h30
+					$session->setBegin(new \DateTime('20:30:00'));
 
 					//Check if next day is premium
 					if ($premium) {
 						//Set length at 7h
 						$session->setLength(new \DateTime('07:00:00'));
 					}
+
+					//Set length at 4h
+					$session->setLength(new \DateTime('04:30:00'));
 				//Check if after
 				} else {
 					//Set begin at 1h
@@ -276,6 +280,13 @@ class ApplicationController extends DefaultController {
 
 				//Set length at 4h
 				$session->setLength(new \DateTime('04:00:00'));
+			//Jardin du Monde => 14h -> 15h
+			} elseif ($short == 'Monde' && $slot == 'Morning') {
+				//Set begin at 14h
+				$session->setBegin(new \DateTime('14:00:00'));
+
+				//Set length at 4h
+				$session->setLength(new \DateTime('01:00:00'));
 			//Combination not supported
 			} else {
 				//Add error in flash message
@@ -406,7 +417,7 @@ class ApplicationController extends DefaultController {
 				//Generate url
 				return $this->redirectToRoute($name, $route);
 			//No route matched
-			} catch(MethodNotAllowedException|ResourceNotFoundException $e) {
+			} catch (MethodNotAllowedException|ResourceNotFoundException $e) {
 				//Unset referer to fallback to default route
 				unset($referer);
 			}